@@ -50,6 +50,7 @@
 #include "constant.h"
 #include "ex.h"
 #include "py_funcs.h"
+#include <factory/factory.h>
 
 #include <gmp.h>
 #include <stdexcept>
@@ -156,6 +157,7 @@ protected:
 	{
 		return 0;
 	}
+        void useries(flint_series_t& fp, int order) const override;
 	bool is_equal_same_type(const basic &other) const override;
 	long calchash() const override;
 
@@ -184,7 +186,6 @@ public:
 	const numeric inverse() const;
 	const numeric step() const;
 	int csgn() const;
-	int compare(const numeric &other) const;
 	bool is_equal(const numeric &other) const;
 	bool is_zero() const;
 	bool is_positive() const;
@@ -214,7 +215,12 @@ public:
 	}
 	long to_long() const;
 	double to_double() const;
-	PyObject* to_pyobject() const;
+	bool is_mpz() const { return t == MPZ; }
+	bool is_mpq() const { return t == MPQ; }
+        const numeric to_bigint() const;
+        const mpz_t& as_mpz() const;
+        const mpq_t& as_mpq() const;
+        PyObject* to_pyobject() const;
         bool is_pyobject() const
         {
                 return t == PYOBJECT;
@@ -222,6 +228,7 @@ public:
 #ifdef PYNAC_HAVE_LIBGIAC
         giac::gen* to_giacgen(giac::context*) const;
 #endif
+        CanonicalForm to_canonical() const;
 
 	const numeric real() const;
 	const numeric imag() const;
@@ -230,6 +237,8 @@ public:
 
 	const numeric exp() const;
 	const numeric log() const;
+	const numeric log(const numeric &b) const;
+	const numeric ratlog(const numeric &b, bool& israt) const;
 	const numeric sin() const;
 	const numeric cos() const;
 	const numeric tan() const;
@@ -304,6 +313,7 @@ void coerce(numeric& new_left, numeric& new_right, const numeric& left, const nu
 
 const numeric exp(const numeric &x);
 const numeric log(const numeric &x);
+const numeric log(const numeric &x, const numeric &b);
 const numeric sin(const numeric &x);
 const numeric cos(const numeric &x);
 const numeric tan(const numeric &x);
@@ -317,8 +327,8 @@ const numeric tanh(const numeric &x);
 const numeric asinh(const numeric &x);
 const numeric acosh(const numeric &x);
 const numeric atanh(const numeric &x);
-const numeric Li2(const numeric &x);
-const numeric Li2(const numeric &x, const numeric &n, PyObject* parent);
+const numeric Li2(const numeric &x, PyObject* parent=nullptr);
+const numeric Li2(const numeric &x, const numeric &n, PyObject* parent=nullptr);
 const numeric stieltjes(const numeric &x);
 const numeric zeta(const numeric &x);
 const numeric lgamma(const numeric &x);
